@@ -117,6 +117,7 @@ void ReviewsModel::setResource(AbstractResource* app)
             QMetaObject::invokeMethod(this, "restartFetching", Qt::QueuedConnection);
         }
         emit rowsChanged();
+        emit resourceChanged();
     }
 }
 
@@ -133,7 +134,7 @@ void ReviewsModel::restartFetching()
 
 void ReviewsModel::fetchMore(const QModelIndex& parent)
 {
-    if(!m_backend || !m_app || m_app->backend()->isFetching() || m_backend->isFetching() || parent.isValid() || !m_canFetchMore)
+    if(!m_backend || !m_app || parent.isValid() || !m_canFetchMore)
         return;
 
     m_lastPage++;
@@ -157,7 +158,7 @@ void ReviewsModel::addReviews(AbstractResource* app, const QList<Review*>& revie
     }
 }
 
-bool ReviewsModel::canFetchMore(const QModelIndex&) const
+bool ReviewsModel::canFetchMore(const QModelIndex& /*parent*/) const
 {
     return m_canFetchMore;
 }
@@ -169,7 +170,7 @@ void ReviewsModel::markUseful(int row, bool useful)
 //     qDebug() << "submitting usefulness" << r->applicationName() << r->id() << useful;
     m_backend->submitUsefulness(r, useful);
     const QModelIndex ind = index(row, 0, QModelIndex());
-    emit dataChanged(ind, ind);
+    emit dataChanged(ind, ind, {UsefulnessTotal, UsefulnessFavorable, UsefulChoice});
 }
 
 void ReviewsModel::deleteReview(int row)
